@@ -4,7 +4,7 @@
 #
 # @author: Younes JAAIDI
 #
-# $Id: f5f16cd884f66c5e7d2632aed6d0c79017119434 $
+# $Id: 3482466378c34d3956ac41f24af0bb03edbe3bee $
 #
 
 from .i_member_delegate import IMemberDelegate
@@ -56,6 +56,9 @@ class SyntheticMember:
     def privateMemberName(self):
         return self._privateMemberName
 
+    def readOnly(self):
+        return self._readOnly
+
     def checkContract(self, argumentName, value):
         # No contract to check.
         if self._contract is None:
